@@ -116,6 +116,9 @@ public:
 
     KConfig *recentAddressConfig() const;
 
+    bool canDeleteLineEdit() const;
+    void setCanDeleteLineEdit(bool inprogressToConfigureCompletion);
+
 public Q_SLOTS:
     void slotShowOUChanged(bool);
 
@@ -158,6 +161,7 @@ private:
     bool mExpandIntern;
     bool mAutoGroupExpand;
     bool mShowRecentAddresses;
+    bool mCanDeleteLineEdit;
 };
 }
 
